package com.khmer9.wa855main.screen.main

import android.media.MediaPlayer
import android.os.Bundle
import android.util.Log
import android.view.View
import androidx.lifecycle.Observer
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.khmer9.wa855main.R
import com.khmer9.wa855main.adapter.MainModuleAdapter
import com.khmer9.wa855main.app.App
import com.khmer9.wa855main.app.DownloadController
import com.khmer9.wa855main.app.ShareActivity
import com.khmer9.wa855main.base.BaseFragment
import com.khmer9.wa855main.config.Config
import com.khmer9.wa855main.extension.btnClick
import com.khmer9.wa855main.remote.User
import kotlinx.android.synthetic.main.layout_sub_module.*

class SubModuleFragment : BaseFragment(R.layout.layout_sub_module) {
    private val shareViewModel = App.injectShareViewModel()
    private lateinit var user: User
    private lateinit var adapter: MainModuleAdapter
    private lateinit var recyclerView: RecyclerView
    private lateinit var betTouch: MediaPlayer
    private val ARG_PARAM1 = "module_id"

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        (requireActivity() as ShareActivity).apply {
            user = loginData.user!!
            betTouch = MediaPlayer.create(this, R.raw.bettouch)
        }
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        (requireActivity() as ShareActivity).apply {
            recyclerView = view.findViewById(R.id.rv_main)

            close_btn.setOnClickListener {
                it.btnClick().subscribe() {
                    (requireActivity() as? ShareActivity)?.apply {
                        onBackPressed()
                    }
                }
            }

            val moduleId = requireArguments().getString(ARG_PARAM1)
            if (!moduleId.isNullOrEmpty()) {
                shareViewModel.remoteSubModule(moduleId)
                shareViewModel.getSubModuleState.observe(viewLifecycleOwner, Observer {
                    setModuleSub(it)
                })
            }
        }
    }

    private fun setModuleSub(state: ResultSubState) {
        if (state.resultList != null) {
            adapter = MainModuleAdapter()
            adapter.submitList(state.resultList)
            recyclerView.setHasFixedSize(true)
            recyclerView.layoutManager = LinearLayoutManager(context)
            recyclerView.adapter = adapter

            adapter.detailButtonListener = { id, appId, sub, comingSoon ->
                if (!id.isNullOrEmpty()) {
                    Log.d("SubModuleClick", id + "-" + appId + "-" + sub)
                    when (appId) {
                        Config.LOTTO_APP_ID -> {
                            (requireActivity() as ShareActivity).apply {
                                val launchIntent = packageManager.getLaunchIntentForPackage(Config.LOTTO_PACKAGE)
                                if (launchIntent != null) {
                                    shareViewModel.getModuleToken(appId, launchIntent)
                                } else {
                                    shareViewModel.getModuleToken(appId, null)
                                    //doDownload(LOTTO_DOWNLOAD)
                                }
                            }
                        }
                        Config.LOTTO_PLUS_APP_ID -> {
                            (requireActivity() as ShareActivity).apply {
                                val launchIntent = packageManager.getLaunchIntentForPackage(Config.LOTTO_PLUS_PACKAGE)
                                if (launchIntent != null) {
                                    shareViewModel.getModuleToken(appId, launchIntent)
                                } else {
                                    shareViewModel.getModuleToken(appId, null)
                                    //doDownload(LOTTO_PLUS_DOWNLOAD)
                                }
                            }
                        }
                        Config.YUKI_APP_ID -> {
                            (requireActivity() as ShareActivity).apply {
                                val launchIntent = packageManager.getLaunchIntentForPackage(Config.YUKI_PACKAGE)
                                if (launchIntent != null) {
                                    shareViewModel.getModuleToken(appId, launchIntent)
                                } else {
                                    shareViewModel.getModuleToken(appId, null)
                                    //doDownload(LOTTO_PLUS_DOWNLOAD)
                                }
                            }
                        }
                        Config.APONG_APP_ID -> {
                            (requireActivity() as ShareActivity).apply {
                                val launchIntent = packageManager.getLaunchIntentForPackage(Config.APONG_PACKAGE)
                                if (launchIntent != null) {
                                    shareViewModel.getModuleToken(appId, launchIntent)
                                } else {
                                    shareViewModel.getModuleToken(appId, null)
                                    //doDownload(LOTTO_PLUS_DOWNLOAD)
                                }
                            }
                        }
                        Config.COCK_FIGHT_APP_ID -> {
                            (requireActivity() as ShareActivity).apply {
                                val launchIntent = packageManager.getLaunchIntentForPackage(Config.COCK_FIGHT_PACKAGE)
                                if (launchIntent != null) {
                                    shareViewModel.getModuleToken(appId, launchIntent)
                                } else {
                                    shareViewModel.getModuleToken(appId, null)
                                    //doDownload(LOTTO_PLUS_DOWNLOAD)
                                }
                            }
                        }
                        Config.RAT_APP_ID -> {
                            (requireActivity() as ShareActivity).apply {
                                val launchIntent = packageManager.getLaunchIntentForPackage(Config.RAT_PACKAGE)
                                if (launchIntent != null) {
                                    shareViewModel.getModuleToken(appId, launchIntent)
                                } else {
                                    shareViewModel.getModuleToken(appId, null)
                                    //doDownload(LOTTO_PLUS_DOWNLOAD)
                                }
                            }
                        }
                        Config.Klaklouk_APP_ID -> {
                            (requireActivity() as ShareActivity).apply {
                                val launchIntent = packageManager.getLaunchIntentForPackage(Config.Klaklouk_PACKAGE)
                                if (launchIntent != null) {
                                    shareViewModel.getModuleToken(appId, launchIntent)
                                } else {
                                    shareViewModel.getModuleToken(appId, null)
                                    //doDownload(LOTTO_PLUS_DOWNLOAD)
                                }
                            }
                        }
                        Config.CARD_APP_ID -> {
                            (requireActivity() as ShareActivity).apply {
                                val launchIntent = packageManager.getLaunchIntentForPackage(Config.CARD_PACKAGE)
                                if (launchIntent != null) {
                                    shareViewModel.getModuleToken(appId, launchIntent)
                                } else {
                                    shareViewModel.getModuleToken(appId, null)
                                    //doDownload(LOTTO_PLUS_DOWNLOAD)
                                }
                            }
                        }
                        Config.TIGER_DRAGON_APP_ID -> {
                        }
                        Config.Yuki_Live_APP_ID -> {
                            (requireActivity() as ShareActivity).apply {
                                val launchIntent = packageManager.getLaunchIntentForPackage(Config.Yuki_Live_PACKAGE)
                                if (launchIntent != null) {
                                    shareViewModel.getModuleToken(appId, launchIntent)
                                } else {
                                    shareViewModel.getModuleToken(appId, null)
                                    //doDownload(LOTTO_PLUS_DOWNLOAD)
                                }
                            }
                        }
                        Config.Lotto_Live_APP_ID -> {
                            (requireActivity() as ShareActivity).apply {
                                val launchIntent = packageManager.getLaunchIntentForPackage(Config.Lotto_Live_PACKAGE)
                                if (launchIntent != null) {
                                    shareViewModel.getModuleToken(appId, launchIntent)
                                } else {
                                    shareViewModel.getModuleToken(appId, null)
                                    //doDownload(LOTTO_PLUS_DOWNLOAD)
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    private fun doDownload(url: String) {
        try {
            (requireActivity() as ShareActivity).apply {
                downloadController = DownloadController(this, url)
                checkStoragePermission()
            }

        } catch (e: Exception) {
            e.printStackTrace()
        }
    }
}